<?php
namespace Deposits_WooCommerce;

if ( !defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

class Settings {
	public function __construct() {
		// Validate callback

		$this->pluginOptions();
	}

	public function pluginOptions() {

		// Set a unique slug-like ID
		$prefix = 'deposits_settings';

		//
		// Create options
		\CSF::createOptions( $prefix, array(
			'menu_title'      => 'Deposit Settings',
			'menu_slug'       => 'deposits_settings',
			'framework_title' => 'Bayna - Deposits & Partial Payments for WooCommerce <small>v' . CIDW_DEPOSITS_VERSION . '</small>',
			'menu_type'       => 'submenu',
			'menu_parent'     => 'codeixer',
			'nav'             => 'inline',
			'theme'           => 'light',
			'footer_text'     => '',
			// menu extras
			'show_bar_menu'   => false,
		) );

		// Create a section
		\CSF::createSection( $prefix, array(
			'title'  => 'General Settings',
			'fields' => array(

				// A text field
				array(
					'id'      => 'select_mode',
					'type'    => 'radio',
					'title'   => __( 'Deposit Mode', 'deposits-for-woocommerce' ),
					'options' => array(
						'only_deposits' => __( 'Order only deposit products or regular ones', 'deposits-for-woocommerce' ),
						'allow_mix'     => __( 'Allow Deposits and regular items together into an order', 'deposits-for-woocommerce' ),

					),
					'default' => 'only_deposits',
				),
				array(
					'id'       => 'global_deposits_mode',
					'type'     => 'switcher',
					'title'    => __( 'Deposits for All Products', 'deposits-for-woocommerce' ),
					'label'    => __( 'Override shop products by Percentage of Amount', 'deposits-for-woocommerce' ),
					'class'    => 'cix-only-pro',
					'subtitle' => 'Available in <a target="_blank" href="https://www.codeixer.com/deposits-payment-plugin-for-woocommerce?utm_source=freemium&utm_medium=settings_page&utm_campaign=upgrade_pro">Pro Version!</a>',

				),

				array(
					'id'      => 'bayna_fully_paid_status',
					'type'    => 'select',
					'default' => 'wc-completed',
					'options' => 'bayna_order_status',
					'title'   => __( 'Deposit Paid Status', 'deposits-for-woocommerce' ),
					'desc'    => __( 'set order status when deposits are paid', 'deposits-for-woocommerce' ),
				),
				array(
					'id'      => 'cidw_payment_gateway',
					'type'    => 'checkbox',
					'title'   => __( 'Disable Payment Methods	', 'deposits-for-woocommerce' ),
					'options' => 'cidw_payment_gateway_list',
				),

			),
		) );

		\CSF::createSection( $prefix, array(
			'title'  => 'Advanced Settings',
			'icon'   => 'fas fa-cogs',
			'fields' => array(
				
				array(
					'id'         => 'cidw_deposit_reminder_type',
					'type'       => 'select',
					'default'    => 'dynamic',
					'class'      => 'cix-only-pro',
					'subtitle'   => 'Available in <a target="_blank" href="https://www.codeixer.com/deposits-payment-plugin-for-woocommerce?utm_source=freemium&utm_medium=settings_page&utm_campaign=upgrade_pro">Pro Version!</a>',
					'options'    => array(
						'dynamic' => __( 'Days after the first payment', 'deposits-for-woocommerce' ),
						'status'  => __( 'Based on Order Status', 'deposits-for-woocommerce' ),
						//  'fixed' => __('Fixed Date', 'deposits-for-woocommerce'),

					),
					'title'      => 'Send Due Deposit Payment Reminder',
					'desc'       => __( 'The due date is the date you want your customer to pay you. <a href="https://www.codeixer.com/docs/how-to-set-up-deposit-payment-reminders-for-customers/" target="_blank">Learn More</a>.', 'deposits-for-woocommerce' ),
					// <br>Note: if you select fixed that then it\'s must need update montly'
				),
				array(
					'id'       => 'cancel_deposits_order',
					'type'     => 'number',
					'default'  => '0',

					'title'    => 'Cancel Order',
					'desc'     => 'Cancel Due deposit order(s) after a certain days of order placed.<br> Default: 0 = orders will not cancel.',
					'class'    => 'cix-only-pro',
					'subtitle' => 'Available in <a target="_blank" href="https://www.codeixer.com/deposits-payment-plugin-for-woocommerce?utm_source=freemium&utm_medium=settings_page&utm_campaign=upgrade_pro">Pro Version!</a>',
				),
				array(
					'id'         => 'cidw_deposit_reminder_dynamic_date',
					'type'       => 'number',
					'default'    => '',
					'class'      => 'cix-only-pro',
					'subtitle'   => 'Available in <a target="_blank" href="https://www.codeixer.com/deposits-payment-plugin-for-woocommerce?utm_source=freemium&utm_medium=settings_page&utm_campaign=upgrade_pro">Pro Version!</a>',
					'title'      => __( 'Set Remainder Date', 'deposits-for-woocommerce' ),
					'desc'       => __( 'Days after the first payment', 'deposits-for-woocommerce' ),
					'dependency' => array( 'cidw_deposit_reminder_type', '==', 'dynamic' ),

				),

				array(
					'id'       => 'exclude_shipping_fee',
					'type'     => 'select',
					'class'    => 'cix-only-pro',
					'subtitle' => 'Available in <a target="_blank" href="https://www.codeixer.com/deposits-payment-plugin-for-woocommerce?utm_source=freemium&utm_medium=settings_page&utm_campaign=upgrade_pro">Pro Version!</a>',
					'title'    => __( 'Shipping Handling', 'deposits-for-woocommerce' ),
					'desc'     => __( 'Choose how to handle shipping.', 'deposits-for-woocommerce' ),
					'options'  => array(
						0 => __( 'With Deposit', 'deposits-for-woocommerce' ),
						1 => __( 'With Future Payment', 'deposits-for-woocommerce' ),
						//'split' => __( 'Split', 'deposits-for-woocommerce' ),

					),

				),
				array(
					'id'       => 'deposit_tax',
					'type'     => 'select',
					'class'    => 'cix-only-pro',
					'subtitle' => 'Available in <a target="_blank" href="https://www.codeixer.com/deposits-payment-plugin-for-woocommerce?utm_source=freemium&utm_medium=settings_page&utm_campaign=upgrade_pro">Pro Version!</a>',
					'desc'     => __( 'Choose how to handle taxes.', 'deposits-for-woocommerce' ),
					'title'    => __( 'Tax Collection', 'deposits-for-woocommerce' ),
					'options'  => array(
						'wdp' => __( 'With Deposit', 'deposits-for-woocommerce' ),
						'wfp' => __( 'With Future Payment', 'deposits-for-woocommerce' ),
						//'split' => __( 'Split', 'deposits-for-woocommerce' ),

					),

				),
				array(
					'id'       => 'deposit_fees',
					'type'     => 'select',
					'class'    => 'cix-only-pro',
					'subtitle' => 'Available in <a target="_blank" href="https://www.codeixer.com/deposits-payment-plugin-for-woocommerce?utm_source=freemium&utm_medium=settings_page&utm_campaign=upgrade_pro">Pro Version!</a>',
					'desc'     => __( 'Choose how to Fees.', 'deposits-for-woocommerce' ),
					'title'    => __( 'Fees Collection', 'deposits-for-woocommerce' ),
					'options'  => array(
						'wdp' => __( 'With Deposit', 'deposits-for-woocommerce' ),
						'wfp' => __( 'With Future Payment', 'deposits-for-woocommerce' ),
						//'split' => __( 'Split', 'deposits-for-woocommerce' ),

					),

				),

			),
		) );
		// Create a section
		\CSF::createSection( $prefix, array(
			'title'  => 'Text & Labels',
			'fields' => array(
				array(
					'id'      => 'regular_notice',
					'type'    => 'text',
					'title'   => __( 'Regular Products Notice', 'deposits-for-woocommerce' ),

					'default' => 'We detected that your cart has Regular products. Please remove them before being able to add this product.',
				),
				array(
					'id'      => 'deposit_notice',
					'type'    => 'text',
					'title'   => __( 'Deposit Products Notice', 'deposits-for-woocommerce' ),

					'default' => 'We detected that your cart has Deposit products. Please remove them before being able to add this product.',
				),
				array(
					'id'      => 'txt_pay_deposit',
					'type'    => 'text',
					'title'   => __( 'Pay Deposit', 'deposits-for-woocommerce' ),
					'default' => 'Pay Deposit',
					'class'   => 'dfwc-text-field',
				),

				array(
					'id'      => 'txt_full_payment',
					'type'    => 'text',
					'title'   => __( 'Full Payment', 'deposits-for-woocommerce' ),
					'default' => 'Full Payment',
					'class'   => 'dfwc-text-field',
				),

				array(
					'id'          => 'txt_deposit_msg',
					'type'        => 'text',
					'title'       => __( 'Deposit Text', 'deposits-for-woocommerce' ),
					'default'     => 'Deposit : {price} Per item',
					'placeholder' => 'Deposit : {price} Per item',
					'class'       => 'dfwc-text-field',
				),

				array(
					'id'      => 'txt_to_deposit_paid',
					'type'    => 'text',
					'title'   => __( 'Paid', 'deposits-for-woocommerce' ),
					'default' => 'Paid:',
					'class'   => 'dfwc-text-field',
				),

				array(
					'id'      => 'txt_to_pay',
					'type'    => 'text',
					'title'   => __( 'To Pay', 'deposits-for-woocommerce' ),
					'default' => 'To Pay:',
					'class'   => 'dfwc-text-field',
				),
				array(
					'id'      => 'txt_to_deposit',
					'type'    => 'text',
					'title'   => __( 'Deposit', 'deposits-for-woocommerce' ),
					'default' => 'Deposit',
					'class'   => 'dfwc-text-field',
				),
				array(
					'id'      => 'txt_to_due_payment',
					'type'    => 'text',
					'title'   => __( 'Due Payment', 'deposits-for-woocommerce' ),
					'default' => 'Due Payment:',
					'class'   => 'dfwc-text-field',
				),
				array(
					'id'      => 'txt_to_deposit_payment_fee',
					'type'    => 'text',
					'title'   => __( 'Deposit Payment Fee', 'deposits-for-woocommerce' ),
					'default' => 'Deposit Payment for order ',
					'class'   => 'dfwc-text-field',
				),
				array(
					'id'      => 'txt_to_due_payment_fee',
					'type'    => 'text',
					'title'   => __( 'Due Payment Fee', 'deposits-for-woocommerce' ),
					'default' => 'Due Payment for order ',
					'class'   => 'dfwc-text-field',
				),

			),
		) );

		// Create a section
		\CSF::createSection( $prefix, array(
			'title'  => 'Radio Style',
			'fields' => array(

				array(
					'id'      => 'cidw_box_active_color',
					'type'    => 'color',
					'title'   => 'Active Color',
					'default' => '#5cb85c',
				),
				array(
					'id'      => 'cidw_radio_theme',
					'type'    => 'radio',
					'default' => 'p-default p-round p-thick',
					'title'   => __( 'Radio Style', 'deposits-for-woocommerce' ),
					'options' => array(
						'p-default p-round p-thick' => 'Round & Thick & Outline',
						'p-default p-round p-fill'  => 'Round & Fill',
						'p-default p-round'         => 'Round',
						'p-default p-curve p-thick' => 'Curve & Thick & Outline',
						'p-default p-curve'         => 'Curve & Outline',
						'p-default p-thick'         => 'Square & Thick & Outline',
						'p-default p-fill'          => 'Square',
						'p-image p-plain'           => 'Image',
					),
				),
				array(
					'id'           => 'cidw_radio_theme_image',
					'type'         => 'upload',
					'title'        => 'Add Radio Image',
					'library'      => 'image',
					'button_title' => 'Add Image',
					'default'      => CIDW_DEPOSITS_ASSETS . '/img/004.png',
					'remove_title' => 'Remove Image',
					'dependency'   => array( 'cidw_radio_theme', '==', 'p-image p-plain' ),
				),

			),
		) );
	}
}
